summaryrefslogtreecommitdiffstats
path: root/generic/tkFrame.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tkFrame.c')
-rw-r--r--generic/tkFrame.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/generic/tkFrame.c b/generic/tkFrame.c
index df370af..696d2f5 100644
--- a/generic/tkFrame.c
+++ b/generic/tkFrame.c
@@ -344,7 +344,7 @@ static void FrameBgImageProc(ClientData clientData,
static void FrameCmdDeletedProc(ClientData clientData);
static void FrameEventProc(ClientData clientData,
XEvent *eventPtr);
-static void FrameLostSlaveProc(ClientData clientData,
+static void FrameLostContentProc(ClientData clientData,
Tk_Window tkwin);
static void FrameRequestProc(ClientData clientData,
Tk_Window tkwin);
@@ -376,7 +376,7 @@ static const Tk_ClassProcs frameClass = {
static const Tk_GeomMgr frameGeomType = {
"labelframe", /* name */
FrameRequestProc, /* requestProc */
- FrameLostSlaveProc /* lostSlaveProc */
+ FrameLostContentProc /* lostContentProc */
};
/*
@@ -732,7 +732,7 @@ CreateFrame(
if (type == TYPE_TOPLEVEL) {
Tcl_DoWhenIdle(MapFrame, framePtr);
}
- Tcl_SetObjResult(interp, TkNewWindowObj(newWin));
+ Tcl_SetObjResult(interp, Tk_NewWindowObj(newWin));
return TCL_OK;
error:
@@ -2016,25 +2016,25 @@ FrameRequestProc(
/*
*--------------------------------------------------------------
*
- * FrameLostSlaveProc --
+ * FrameLostContentProc --
*
* This function is invoked by Tk whenever some other geometry claims
* control over a slave that used to be managed by us.
*
* Results:
* None.
*
* Side effects:
* Forgets all frame-related information about the slave.
*
*--------------------------------------------------------------
*/
static void
-FrameLostSlaveProc(
- ClientData clientData, /* Frame structure for slave window that was
+FrameLostContentProc(
+ ClientData clientData, /* Frame structure for content window window that was
* stolen away. */
- Tk_Window tkwin) /* Tk's handle for the slave window. */
+ Tk_Window tkwin) /* Tk's handle for the content window window. */
{
Frame *framePtr = (Frame *)clientData;
Labelframe *labelframePtr = (Labelframe *)clientData;
@@ -2016,25 +2016,25 @@ FrameRequestProc(
*
* This function is invoked by Tk whenever some other geometry claims
- * control over a slave that used to be managed by us.
+ * control over a content window that used to be managed by us.
*
* Results:
@@ -2016,25 +2016,25 @@ FrameRequestProc(
*
* Side effects:
- * Forgets all frame-related information about the slave.
+ * Forgets all frame-related information about the content window.
*
*--------------------------------------------------------------